from xaal.lib import Engine,tools
from xaal.schemas import devices
from xaal.monitor import Monitor
import platform,time

PKG_NAME = 'btn_relay_labo'


def UUID(uuids):
    r = []
    for k in uuids:
        r.append(tools.get_uuid(k))
    return r


LAMPS=  UUID(['ccc44227-d4fc-46eb-8578-159e2c47da03','ccc44227-d4fc-46eb-8578-159e2c47da04','ccc44227-d4fc-46eb-8578-159e2c47da05',
              'ccc44227-d4fc-46eb-8578-159e2c47da06','ccc44227-d4fc-46eb-8578-159e2c47da07','ccc44227-d4fc-46eb-8578-159e2c47da08'])

SPOTS = UUID(['6265eb30-8c59-11e9-98b1-b827ebe99201',])

# Edisio labo
BTNS  = UUID(['743034ca-c2f0-11e8-9485-a40074bcb601','743034ca-c2f0-11e8-9485-a40074bcb603','743034ca-c2f0-11e8-9485-a40074bcb605',
              '743034ca-c2f0-11e8-9485-a40074bcb607','743034ca-c2f0-11e8-9485-a40074bcb608'])

# Aquara sw1
AQUARA= UUID(['1ec6bbd0-20b5-11e9-b352-a4badbf92500'])
SDB   = UUID(['fb1f8648-20ba-11e9-b352-a4badbf92500','fb1f8648-20ba-11e9-b352-a4badbf92501','fb1f8648-20ba-11e9-b352-a4badbf92502'])
SCEN  = UUID(['00796898-20bb-11e9-b352-a4badbf92500','00796898-20bb-11e9-b352-a4badbf92501','00796898-20bb-11e9-b352-a4badbf92502'])


# Edisio bureau
#BTNS = ['c4b33536-c314-11e8-a5d6-000673742b01','c4b33536-c314-11e8-a5d6-000673742b03','c4b33536-c314-11e8-a5d6-000673742b05',
#        'c4b33536-c314-11e8-a5d6-000673742b07','c4b33536-c314-11e8-a5d6-000673742b08']


SHUTERS = UUID(['e4b05165-be5d-46d5-acd0-4da7be1158ed','2fe70f46-3ece-44d1-af34-2d82e10fb854'])
SIRENS  = UUID(['980a639c-20b1-11e9-8d70-a4badbf92501',])

LAMPS_A = [LAMPS[0], LAMPS[2], LAMPS[5]]
LAMPS_B = [LAMPS[1], LAMPS[3], LAMPS[4]]

mon = None


def send(targets,action,body=None):
    global mon
    engine = mon.dev.engine
    engine.send_request(dev,targets,action,body)

def search_for_light(lamps):
    for l in lamps:
        dev = mon.devices.get_with_addr(l)
        if dev:
            light = dev.attributes.get('light',None)
            if light:
                return True
    return False

def on_off_light(lamps):
    if search_for_light(lamps):
        send(lamps,'off')
        return False
    else:
        send(lamps,'on')
        return True

def handle_msg(msg):
    if not msg.is_notify():
        return
    # search for the buttons 
    if msg.action == 'click':
        if msg.source == BTNS[0]:
            on_off_light(LAMPS_A)

        if msg.source == BTNS[1]:
            on_off_light(LAMPS_B)

        # btn du milieu / on éteint tout
        if msg.source == BTNS[2]:
            on_off_light(LAMPS)
            #send(SHUTERS,'stop')

        if msg.source in AQUARA:
            if on_off_light(LAMPS):
                #send([SHUTERS[0],],'up')
                #send([SHUTERS[1],],'up')
                pass
            else:
                #send([SHUTERS[0],],'down')
                #send([SHUTERS[1],],'down')
                pass

        if msg.source == SDB[0]:
            send([LAMPS[3],],'toggle')

        if msg.source == SCEN[0]:
            # "soirée TV"
            send([SHUTERS[0]],'down')
            send(LAMPS,'off')
            send(SPOTS,'on')
            send([SHUTERS[1]],'down')
            
        if msg.source == SCEN[1]:
            # "Début journée"
            send([SHUTERS[0]],'up')
            send([LAMPS[3],],'on')
            send(SPOTS,'off')
            send([SHUTERS[1]],'up')

        if msg.source == SCEN[2]:
            # "stop"
            send([SHUTERS[0]],'stop')
            send([SHUTERS[1]],'stop')
            send(SIRENS,'stop')
            
    if msg.action == 'double_click':
        if msg.source in AQUARA:
            send([SHUTERS[0],],'stop')
            send([SHUTERS[1],],'stop')
            send(SIRENS,'stop')
            
    if msg.action == 'attributesChange':
        #print(msg)
        if msg.source == tools.get_uuid('d9993018-20b1-11e9-a250-a4badbf92500'):
            pres = msg.body.get('presence')
            light = mon.devices.get_with_addr(LAMPS[3]).attributes.get('light')
            print("pres & light %s/%s" % (pres,light)) 
            if pres == False and light == True:
                send(SIRENS,'play')
                print('Alarme..')
            
def main():
    global dev
    global mon
    dev = devices.basic()
    dev.info = '%s@%s' % (PKG_NAME,platform.node())
    engine = Engine()
    engine.add_device(dev)
    engine.add_rx_handler(handle_msg)
    mon = Monitor(dev)
    engine.run()

if __name__ == '__main__':
    try:
        eng = main()
    except KeyboardInterrupt:
        print('Bye bye')
